@@ -4,7 +4,7 @@ import datetime
 import socket
 from msmart.security import security
 
-VERSION = '0.1.23'
+VERSION = '0.1.24'
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -45,7 +45,7 @@ class lan:
         finally:
             sock.close()
         _LOGGER.debug("Received from {}:{} {}".format(
-            self.device_ip, self.device_port, message.hex()))
+            self.device_ip, self.device_port, response.hex()))
         return response
 
     def encode(self, data: bytearray):
